@@ -1,12 +1,15 @@
 // -*- C++ -*-
 
-#include "pomp_internal.h"
 #include <Rdefines.h>
+#include <string.h>
+
+#include "pomp_internal.h"
 
 SEXP simulation_computations (SEXP object, SEXP params, SEXP times, SEXP t0, SEXP nsim, SEXP obs, SEXP states)
 {
   int nprotect = 0;
-  SEXP xstart, x, xx, x0, y, p, alltimes, coef, yy, offset;
+  SEXP xstart, x, y, alltimes, coef, yy, offset;
+  SEXP p = R_NilValue, x0 = R_NilValue, xx = R_NilValue;
   SEXP ans, ans_names;
   SEXP po, popo;
   SEXP statenames, paramnames, obsnames, statedim, obsdim;
@@ -14,10 +17,10 @@ SEXP simulation_computations (SEXP object, SEXP params, SEXP times, SEXP t0, SEX
   int qobs, qstates;
   int *dim, dims[3];
   double *s, *t, *xs, *xt, *ys, *yt, *ps, *pt, tt;
-  int i, j, k;
+  int i, j, k, np, nx;
 
   PROTECT(offset = NEW_INTEGER(1)); nprotect++;
-  INTEGER(offset)[0] = 1;
+  *(INTEGER(offset)) = 1;
 
   nsims = INTEGER(AS_INTEGER(nsim))[0]; // number of simulations per parameter set
   if (LENGTH(nsim)>1)
@@ -25,8 +28,8 @@ SEXP simulation_computations (SEXP object, SEXP params, SEXP times, SEXP t0, SEX
   if (nsims < 1) 
     return R_NilValue;		// no work to do  
 
-  qobs = LOGICAL(AS_LOGICAL(obs))[0];	    // 'obs' flag set?
-  qstates = LOGICAL(AS_LOGICAL(states))[0]; // 'states' flag set?
+  qobs = *(LOGICAL(AS_LOGICAL(obs)));	    // 'obs' flag set?
+  qstates = *(LOGICAL(AS_LOGICAL(states))); // 'states' flag set?
 
   PROTECT(paramnames = GET_ROWNAMES(GET_DIMNAMES(params))); nprotect++;
   dim = INTEGER(GET_DIM(params));
@@ -47,7 +50,7 @@ SEXP simulation_computations (SEXP object, SEXP params, SEXP times, SEXP t0, SEX
     error("if 'times' is empty, there is no work to do");
   
   PROTECT(alltimes = NEW_NUMERIC(ntimes+1)); nprotect++;
-  tt = REAL(t0)[0];
+  tt = *(REAL(t0));
   s = REAL(times);
   t = REAL(alltimes);
 
@@ -64,11 +67,7 @@ SEXP simulation_computations (SEXP object, SEXP params, SEXP times, SEXP t0, SEX
   }
 
   // call 'rprocess' to simulate state process
-  if (nsims == 1) {		// only one simulation per parameter set
-
-    PROTECT(x = do_rprocess(object,xstart,alltimes,params,offset)); nprotect++;
-
-  } else {			// nsim > 1
+  if (nsims > 1) {	     // multiple simulations per parameter set
 
     dims[0] = npars; dims[1] = nreps;
     PROTECT(p = makearray(2,dims)); nprotect++;
@@ -79,15 +78,19 @@ SEXP simulation_computations (SEXP object, SEXP params, SEXP times, SEXP t0, SEX
     setrownames(x0,statenames,2);
 
     // make 'nsims' copies of the parameters and initial states
-    for (k = 0, pt = REAL(p), xt = REAL(x0); k < nsims; k++) {
-      for (j = 0, ps = REAL(params), xs = REAL(xstart); j < nparsets; j++) {
-	for (i = 0; i < npars; i++, pt++, ps++) *pt = *ps;
-	for (i = 0; i < nvars; i++, xt++, xs++) *xt = *xs;
-      }
+    ps = REAL(params); np = LENGTH(params);
+    xs = REAL(xstart); nx = LENGTH(xstart);
+    for (k = 0, pt = REAL(p), xt = REAL(x0); k < nsims; k++, pt += np, xt += nx) {
+      memcpy(pt,ps,np*sizeof(double));
+      memcpy(xt,xs,nx*sizeof(double));
     }
 
     PROTECT(x = do_rprocess(object,x0,alltimes,p,offset)); nprotect++;
 
+  } else {			// nsim == 1
+
+    PROTECT(x = do_rprocess(object,xstart,alltimes,params,offset)); nprotect++;
+
   }
 
   if (!qobs && qstates) {	// obs=F,states=T: return states only
@@ -95,12 +98,12 @@ SEXP simulation_computations (SEXP object, SEXP params, SEXP times, SEXP t0, SEX
     UNPROTECT(nprotect);
     return x;
 
-  } else {
+  } else {			// we must do 'rmeasure'
 
-    if (nsims == 1) {
-      PROTECT(y = do_rmeasure(object,x,times,params)); nprotect++;
-    } else {
+    if (nsims > 1) {
       PROTECT(y = do_rmeasure(object,x,times,p)); nprotect++;
+    } else {
+      PROTECT(y = do_rmeasure(object,x,times,params)); nprotect++;
     }
     
     if (qobs) {
@@ -109,9 +112,9 @@ SEXP simulation_computations (SEXP object, SEXP params, SEXP times, SEXP t0, SEX
 
 	PROTECT(ans = NEW_LIST(2)); nprotect++;
 	PROTECT(ans_names = NEW_CHARACTER(2)); nprotect++;
-	SET_NAMES(ans,ans_names);
 	SET_STRING_ELT(ans_names,0,mkChar("states"));
 	SET_STRING_ELT(ans_names,1,mkChar("obs"));
+	SET_NAMES(ans,ans_names);
 	SET_ELEMENT(ans,0,x);
 	SET_ELEMENT(ans,1,y);
 	UNPROTECT(nprotect);
@@ -157,7 +160,7 @@ SEXP simulation_computations (SEXP object, SEXP params, SEXP times, SEXP t0, SEX
 
 	ps = REAL(params);
 	pt = REAL(GET_SLOT(po,install("params")));
-	for (i = 0; i < npars; i++, ps++, pt++) *pt = *ps;
+	memcpy(pt,ps,npars*sizeof(double));
 
 	UNPROTECT(nprotect);
 	return po;
@@ -168,32 +171,32 @@ SEXP simulation_computations (SEXP object, SEXP params, SEXP times, SEXP t0, SEX
 	PROTECT(ans = NEW_LIST(nreps)); nprotect++; 
 
 	// create an array for the 'states' slot
-	PROTECT(xx = makearray(2,INTEGER(statedim))); nprotect++;
+	PROTECT(xx = makearray(2,INTEGER(statedim)));
 	setrownames(xx,statenames,2);
 	SET_SLOT(po,install("states"),xx);
+	UNPROTECT(1);
 
 	// create an array for the 'data' slot
-	PROTECT(yy = makearray(2,INTEGER(obsdim))); nprotect++;
+	PROTECT(yy = makearray(2,INTEGER(obsdim)));
 	setrownames(yy,obsnames,2);
 	SET_SLOT(po,install("data"),yy);
+	UNPROTECT(1);
 
 	xs = REAL(x); 
 	ys = REAL(y); 
-	if (nsims == 1)
-	  ps = REAL(params);
-	else
-	  ps = REAL(p);
+	ps = (nsims > 1) ? REAL(p) : REAL(params);
 
-	for (k = 0; k < nreps; k++) { // loop over replicates
+	for (k = 0; k < nreps; k++, ps += npars) { // loop over replicates
 
 	  PROTECT(popo = duplicate(po));
 
+	  // copy parameters
+	  pt = REAL(GET_SLOT(popo,install("params")));
+	  memcpy(pt,ps,npars*sizeof(double)); 
+	  
 	  // copy x[,k,] and y[,k,] into popo
 	  xt = REAL(GET_SLOT(popo,install("states"))); 
 	  yt = REAL(GET_SLOT(popo,install("data")));
-	  pt = REAL(GET_SLOT(popo,install("params")));
-
-	  for (i = 0; i < npars; i++, pt++, ps++) *pt = *ps;
 	  for (j = 0; j < ntimes; j++) {
 	    for (i = 0; i < nvars; i++, xt++) *xt = xs[i+nvars*(k+nreps*j)];
 	    for (i = 0; i < nobs; i++, yt++) *yt = ys[i+nobs*(k+nreps*j)];
